@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Test::Warnings; # git description: v0.033-4-gb16c52b
+package Test::Warnings; # git description: v0.034-3-gbad3366
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Test for warnings and the lack of them
 # KEYWORDS: testing tests warnings
 
-our $VERSION = '0.034';
+our $VERSION = '0.035';
 
 use parent 'Exporter';
 use Test::Builder;
@@ -106,7 +106,7 @@ sub warning(&) {
 # so we do not check again via END
 sub done_testing {
     if (Test2::Tools::Basic->can('done_testing')) {
-        if (not $no_end_test) {
+        if (not $no_end_test and not $done_testing_called) {
             # we could use $ctx to create the test, which means not having to adjust Level,
             # but then we need to make _builder Test2-compatible, which seems like a PITA.
             local $Test::Builder::Level = $Test::Builder::Level + 3;
@@ -120,7 +120,7 @@ sub done_testing {
         # only do this at the end of all tests, not at the end of a subtest
         my $builder = _builder;
         my $in_subtest_sub = $builder->can('in_subtest');
-        if (not $no_end_test
+        if (not $no_end_test and not $done_testing_called
             and not ($in_subtest_sub ? $builder->$in_subtest_sub : $builder->parent)) {
             local $Test::Builder::Level = $Test::Builder::Level + 3;
             had_no_warnings('no (unexpected) warnings (via done_testing)');
@@ -134,6 +134,28 @@ sub done_testing {
     }
 }
 
+# we also monkey-patch Test::Builder::done_testing (which is called by Test::More::done_testing),
+# in case Test::More was loaded after Test::Warnings and therefore its version of done_testing was
+# imported into the test rather than ours.
+if (Test::Builder->can('done_testing')) {
+    no strict 'refs';
+    my $orig = *{'Test::Builder::done_testing'}{CODE};
+    no warnings 'redefine';
+    *{'Test::Builder::done_testing'} = sub {
+        # only do this at the end of all tests, not at the end of a subtest
+        my $builder = _builder;
+        my $in_subtest_sub = $builder->can('in_subtest');
+        if (not $no_end_test and not $done_testing_called
+            and not ($in_subtest_sub ? $builder->$in_subtest_sub : $builder->parent)) {
+            local $Test::Builder::Level = $Test::Builder::Level + 3;
+            had_no_warnings('no (unexpected) warnings (via done_testing)');
+            $done_testing_called = 1;
+        }
+
+        $orig->(@_);
+    };
+}
+
 END {
     if (not $no_end_test
         and not $done_testing_called
@@ -214,7 +236,7 @@ Test::Warnings - Test for warnings and the lack of them
 
 =head1 VERSION
 
-version 0.034
+version 0.035
 
 =head1 SYNOPSIS
 
